@@ -29,6 +29,12 @@ BUYBACKPROGRAM_PRICE_SOURCE_NAME = clean_setting(
     "BUYBACKPROGRAM_PRICE_SOURCE_NAME", "Jita"
 )
 
+BUYBACKPROGRAM_PRICE_METHOD = clean_setting("BUYBACKPROGRAM_PRICE_METHOD", "Fuzzwork")
+
+BUYBACKPROGRAM_PRICE_JANICE_API_KEY = clean_setting(
+    "BUYBACKPROGRAM_PRICE_JANICE_API_KEY", ""
+)
+
 
 def allianceauth_discordbot_active():
     """
