@@ -5,13 +5,10 @@ from django.contrib.auth.decorators import login_required, permission_required
 from django.db.models import Q
 from django.shortcuts import render
 from django.utils import timezone
-from esi.clients import EsiClientProvider
-from esi.decorators import tokens_required
 from eveuniverse.models import EveEntity
 
 from allianceauth.authentication.models import CharacterOwnership
 from allianceauth.services.hooks import get_extension_logger
-from app_utils.esi import fetch_esi_status
 
 from buybackprogram.notes import (
     note_missing_from_contract,
@@ -31,28 +28,9 @@ from ..models import (
 logger = get_extension_logger(__name__)
 
 
-def get_location_name(token, structid):
-    esi = EsiClientProvider()
-    status = fetch_esi_status()
-    if not status.is_online or status.error_limit_remain < 5:
-        return "Unknown"
-    if structid <= 100000000:  # likely to be NPC station
-        return EveEntity.objects.resolve_name(structid)
-
-    operation = esi.client.Universe.get_universe_structures_structure_id(
-        structure_id=structid, token=token
-    )
-    operation.request_config.also_return_response = True
-    label, response = operation.result()
-    if response.status_code != 200:
-        return "Unknown"
-    return label["name"]
-
-
-@tokens_required(scopes="esi-universe.read_structures.v1")
 @login_required
 @permission_required("buybackprogram.basic_access")
-def my_stats(request, token):
+def my_stats(request):
 
     # List for valid contracts to be displayed
     valid_contracts = []
@@ -104,11 +82,6 @@ def my_stats(request, token):
             tracking.contract.assignee_id
         )
 
-        # Get location name for contract
-        tracking.contract.location = get_location_name(
-            token[0].valid_access_token(), tracking.contract.start_location_id
-        )
-
         # Add contract to the valid contract list
         valid_contracts.append(tracking)
 
@@ -409,10 +382,9 @@ def program_performance(request, program_pk):
     return render(request, "buybackprogram/performance.html", context)
 
 
-@tokens_required(scopes="esi-universe.read_structures.v1")
 @login_required
 @permission_required("buybackprogram.manage_programs")
-def program_stats(request, token):
+def program_stats(request):
 
     # List for valid contracts to be displayed
     valid_contracts = []
@@ -472,11 +444,6 @@ def program_stats(request, token):
             tracking.contract.assignee_id
         )
 
-        # Get location name for contract
-        tracking.contract.location = get_location_name(
-            token[0].valid_access_token(), tracking.contract.start_location_id
-        )
-
         # Add contract to the valid contract list
         valid_contracts.append(tracking)
 
@@ -489,10 +456,9 @@ def program_stats(request, token):
     return render(request, "buybackprogram/stats.html", context)
 
 
-@tokens_required(scopes="esi-universe.read_structures.v1")
 @login_required
 @permission_required("buybackprogram.see_all_statics")
-def program_stats_all(request, token):
+def program_stats_all(request):
 
     # List for valid contracts to be displayed
     valid_contracts = []
@@ -538,11 +504,6 @@ def program_stats_all(request, token):
             tracking.contract.assignee_id
         )
 
-        # Get location name for contract
-        tracking.contract.location = get_location_name(
-            token[0].valid_access_token(), tracking.contract.start_location_id
-        )
-
         valid_contracts.append(tracking)
 
     context = {
@@ -554,18 +515,12 @@ def program_stats_all(request, token):
     return render(request, "buybackprogram/stats.html", context)
 
 
-@tokens_required(scopes="esi-universe.read_structures.v1")
 @login_required
 @permission_required("buybackprogram.basic_access")
-def contract_details(request, token, contract_title):
+def contract_details(request, contract_title):
 
     contract = Contract.objects.get(title__contains=contract_title)
 
-    # Get location name for contract
-    contract.location = get_location_name(
-        token[0].valid_access_token(), contract.start_location_id
-    )
-
     # Get notes for this contract
     notes = ContractNotification.objects.filter(contract=contract)
 
